# Welcome to the pifm repository

pifm is a tool to teach in-formal methods.

## Initial setup

To use the system, you can do the following:

```sh
$ git clone git@github.com:COMP6721UNSW/pifm.git pifm
$ cd pifm
$ run_pifm ./my_example.py
```


